@@ -69,7 +69,7 @@ struct caitsith_exports {
 #endif
 	struct task_struct * (*find_task_by_vpid)(pid_t nr);
 	struct task_struct * (*find_task_by_pid_ns)(pid_t nr,
-						     struct pid_namespace *ns);
+						    struct pid_namespace *ns);
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 29)
 	size_t (*ksize)(const void *objp);
 #endif
@@ -80,80 +80,86 @@ struct caitsith_operations {
 	void (*check_profile)(void);
 	int (*chroot_permission)(const struct path *path);
 	int (*pivot_root_permission)(const struct path *old_path,
-				      const struct path *new_path);
+				     const struct path *new_path);
 	int (*mount_permission)(const char *dev_name, const struct path *path,
-				 const char *type, unsigned long flags,
-				 void *data_page);
+				const char *type, unsigned long flags,
+				void *data_page);
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 2, 0)
 	int (*move_mount_permission) (const struct path *from_path,
 				      const struct path *to_path);
 #endif
 	int (*umount_permission)(struct vfsmount *mnt, int flags);
-
 	_Bool(*lport_reserved) (const u16 port); /* Not implemented. */
 #if LINUX_VERSION_CODE <= KERNEL_VERSION(2, 6, 32)
 	void (*save_open_mode)(int mode);
 	void (*clear_open_mode)(void);
 	int (*open_permission)(struct dentry *dentry, struct vfsmount *mnt,
-				const int flag);
+			       const int flag);
 #else
 	int (*open_permission)(struct file *file);
 #endif
 	int (*ptrace_permission)(long request, long pid);
 	int (*ioctl_permission)(struct file *filp, unsigned int cmd,
-				 unsigned long arg);
+				unsigned long arg);
 	int (*parse_table)(int __user *name, int nlen, void __user *oldval,
-			    void __user *newval, struct ctl_table *table);
+			   void __user *newval, struct ctl_table *table);
 	_Bool(*capable) (const u8 operation);
 	int (*mknod_permission)(struct dentry *dentry, struct vfsmount *mnt,
-				 unsigned int mode, unsigned int dev);
+				unsigned int mode, unsigned int dev);
 	int (*mkdir_permission)(struct dentry *dentry, struct vfsmount *mnt,
-				 unsigned int mode);
+				unsigned int mode);
 	int (*rmdir_permission)(struct dentry *dentry, struct vfsmount *mnt);
 	int (*unlink_permission)(struct dentry *dentry, struct vfsmount *mnt);
 	int (*symlink_permission)(struct dentry *dentry, struct vfsmount *mnt,
-				   const char *from);
+				  const char *from);
 	int (*truncate_permission)(struct dentry *dentry,
-				    struct vfsmount *mnt);
+				   struct vfsmount *mnt);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 19, 0)
 	int (*rename_permission)(struct dentry *old_dentry,
-				  struct dentry *new_dentry,
-				  struct vfsmount *mnt);
+				 struct dentry *new_dentry,
+				 struct vfsmount *mnt,
+				 const unsigned int flags);
+#else
+	int (*rename_permission)(struct dentry *old_dentry,
+				 struct dentry *new_dentry,
+				 struct vfsmount *mnt);
+#endif
 	int (*link_permission)(struct dentry *old_dentry,
-				struct dentry *new_dentry,
-				struct vfsmount *mnt);
+			       struct dentry *new_dentry,
+			       struct vfsmount *mnt);
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 30)
 	int (*open_exec_permission)(struct dentry *dentry,
-				     struct vfsmount *mnt);
+				    struct vfsmount *mnt);
 	int (*uselib_permission)(struct dentry *dentry, struct vfsmount *mnt);
 #endif
 	int (*fcntl_permission)(struct file *file, unsigned int cmd,
-				 unsigned long arg);
+				unsigned long arg);
 	int (*kill_permission)(pid_t pid, int sig);
 	int (*tgkill_permission)(pid_t tgid, pid_t pid, int sig);
 	int (*tkill_permission)(pid_t pid, int sig);
 	int (*socket_create_permission)(int family, int type, int protocol);
 	int (*socket_listen_permission)(struct socket *sock);
 	int (*socket_connect_permission)(struct socket *sock,
-					  struct sockaddr *addr, int addr_len);
+					 struct sockaddr *addr, int addr_len);
 	int (*socket_bind_permission)(struct socket *sock,
-				       struct sockaddr *addr, int addr_len);
+				      struct sockaddr *addr, int addr_len);
 	int (*socket_post_accept_permission)(struct socket *sock,
-					      struct socket *newsock);
+					     struct socket *newsock);
 	int (*socket_sendmsg_permission)(struct socket *sock,
-					  struct msghdr *msg, int size);
+					 struct msghdr *msg, int size);
 	int (*socket_post_recvmsg_permission)(struct sock *sk,
-					       struct sk_buff *skb, int flags);
+					      struct sk_buff *skb, int flags);
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 5, 0)
 	int (*chown_permission)(struct dentry *dentry, struct vfsmount *mnt,
-				 kuid_t user, kgid_t group);
+				kuid_t user, kgid_t group);
 #else
 	int (*chown_permission)(struct dentry *dentry, struct vfsmount *mnt,
-				 uid_t user, gid_t group);
+				uid_t user, gid_t group);
 #endif
 	int (*chmod_permission)(struct dentry *dentry, struct vfsmount *mnt,
-				 mode_t mode);
+				mode_t mode);
 	int (*getattr_permission)(struct vfsmount *mnt,
-				   struct dentry *dentry);
+				  struct dentry *dentry);
 	int (*sigqueue_permission)(pid_t pid, int sig);
 	int (*tgsigqueue_permission)(pid_t tgid, pid_t pid, int sig);
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 8, 0)
@@ -163,7 +169,7 @@ struct caitsith_operations {
 	int (*search_binary_handler)(struct linux_binprm *bprm);
 #else
 	int (*search_binary_handler)(struct linux_binprm *bprm,
-				      struct pt_regs *regs);
+				     struct pt_regs *regs);
 #endif
 #ifdef CONFIG_CAITSITH_USE_EXTERNAL_TASK_SECURITY
 	int (*alloc_task_security)(const struct task_struct *task);
@@ -328,6 +334,17 @@ static inline int ccs_truncate_permission(struct dentry *dentry,
 	return func ? func(dentry, mnt) : 0;
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 19, 0)
+static inline int ccs_rename_permission(struct dentry *old_dentry,
+					struct dentry *new_dentry,
+					struct vfsmount *mnt,
+					const unsigned int flags)
+{
+	int (*func)(struct dentry *, struct dentry *, struct vfsmount *,
+		    const unsigned int) = caitsith_ops.rename_permission;
+	return func ? func(old_dentry, new_dentry, mnt, flags) : 0;
+}
+#else
 static inline int ccs_rename_permission(struct dentry *old_dentry,
 					struct dentry *new_dentry,
 					struct vfsmount *mnt)
@@ -336,6 +353,7 @@ static inline int ccs_rename_permission(struct dentry *old_dentry,
 		= caitsith_ops.rename_permission;
 	return func ? func(old_dentry, new_dentry, mnt) : 0;
 }
+#endif
 
 static inline int ccs_link_permission(struct dentry *old_dentry,
 				      struct dentry *new_dentry,
@@ -541,12 +559,22 @@ static inline int ccs_truncate_permission(struct dentry *dentry,
 	return 0;
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 19, 0)
+static inline int ccs_rename_permission(struct dentry *old_dentry,
+					struct dentry *new_dentry,
+					struct vfsmount *mnt,
+					const unsigned int flags)
+{
+	return 0;
+}
+#else
 static inline int ccs_rename_permission(struct dentry *old_dentry,
 					struct dentry *new_dentry,
 					struct vfsmount *mnt)
 {
 	return 0;
 }
+#endif
 
 static inline int ccs_link_permission(struct dentry *old_dentry,
 				      struct dentry *new_dentry,
